/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Visual tab for CropFields
 * @author Gerben Feenstra
 */
@MultiViewElement.Registration(displayName = "#CropFieldDataElement_tab_name",
iconBase = "nl/cloudfarming/client/productionunit/draw_island16.png",
mimeType = CropField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "CropFieldVisual",
position = 1000)
@Messages(value={
    "CropFieldDataElement_tab_name=Data",
    "CropFieldDataElement_panel_header=Crop field data"
})
public final class CropFieldDataElement extends JPanel implements MultiViewElement, HelpCtx.Provider {

    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private final Lookup lkp;

    public CropFieldDataElement(Lookup lkp) {
        this.lkp = lkp;
        CropField cropField = lkp.lookup(CropField.class);
        assert cropField != null:" lookup should contain a CropField Object";
        
        // Update tabname when changed
        cropField.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (Field.PROP_NAME.equals(evt.getPropertyName())) {
                    updateName();
                }
            }
        });
                    
        this.setLayout(new BorderLayout());
        ASBodyPanel contentPanel = new ASBodyPanel(new CropFieldDataPanel(cropField));
        contentPanel.setTitle(Bundle.CropFieldDataElement_panel_header());
        contentPanel.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/productionunit/draw_island32.png", true));
        add(contentPanel);
    }

    @Override
    public String getName() {
        return "CropFieldDataElement";
    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lkp;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            CropField cropField = getLookup().lookup(CropField.class);
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(cropField.getName());
            tc.setDisplayName(cropField.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.cropfield.type.about");
    } 
}
