/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.productionunit;

import com.vividsolutions.jts.geom.Geometry;
import java.util.Date;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.geoviewer.SplitGeometryHandler;
import org.openide.nodes.Node;

/**
 * Split handler for {@link CropField}
 * @author johan
 */
public class CropFieldSplitHandler extends SplitGeometryHandler {
    private final CropField sourceCropField;

    public CropFieldSplitHandler(CropField cropField) {
        this.sourceCropField = cropField;
    }

    @Override
    public Geometry getSource() {
        return sourceCropField.getGeometry();
    }

    @Override
    public boolean handle(Geometry[] geometries, Node sourceNode) {
        CropProductionUnit cropProductionUnit = sourceCropField.getParent();
        
        if (cropProductionUnit == null) {
            //TODO: log message in GUI
            return false;
        }

        for (int i = 0; i < geometries.length; i++) {
            // create new cropfield based on original cropfield and new geometry,
            CropField newCropField = new CropField(sourceCropField);
            newCropField.setGeometry(geometries[i]);
            // TODO: calc area in Ha.
            newCropField.setName(sourceCropField.getName() + "-part-" + i);
            
            // add to same CropProductionUnit as original:
            cropProductionUnit.addCropField(newCropField);
            
            addToMap(new CropFieldNode(newCropField));
        }
        //mark the original CropField as expired by setting it's end date
        sourceCropField.setEndDate(new Date());
        removeFromMap(sourceNode);
        
        return true;
    }
    
}
