/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Top component which displays an overview of {@link CropProductionUnit}
 * properties.
 *
 * @author Merijn Zengers
 */
@MultiViewElement.Registration(displayName = "#CTL_CropProductionUnitDataElement",
iconBase = "nl/cloudfarming/client/productionunit/green16.png",
mimeType = CropProductionUnit.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "nl-cloudfarming-client-productionunit-CropProductionUnitDataElement",
position = 1000)
@Messages({
    "CTL_CropProductionUnitDataElement=Production unit overview"
})
public final class CropProductionUnitDataElement extends CropProductionUnitDetailsController<CropProductionUnitDataPanel> implements MultiViewElement {

    private CropProductionUnit cropProductionUnit;
    private transient MultiViewElementCallback callback;
    private JToolBar toolbar = new JToolBar();
    private Lookup lookup;
    private NameUpdater nameUpdater; 

    /**
     * Create a new CropProductionUnitDataElement expects a
     * {@link CropProductionUnit} in the passed lookup
     *
     * @param lookup
     */
    public CropProductionUnitDataElement(Lookup lookup) {
        super(new CropProductionUnitDataPanel(lookup.lookup(CropProductionUnit.class)));
        this.lookup = lookup;
        this.cropProductionUnit = lookup.lookup(CropProductionUnit.class);
    }

    @Override
    public JComponent getVisualRepresentation() {
        return super.getComponent();
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public void componentOpened() {
        nameUpdater = new NameUpdater();
        cropProductionUnit.addPropertyChangeListener(nameUpdater);
    }

    @Override
    public void componentClosed() {
        cropProductionUnit.removePropertyChangeListener(nameUpdater);
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback mvec) {
        this.callback = mvec;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(cropProductionUnit.getName());
            tc.setDisplayName(cropProductionUnit.getName());
            tc.setName(cropProductionUnit.getName());
            tc.setToolTipText(cropProductionUnit.getName());
        }
    }

    /**
     * Listens to name changes on {@link CropProductionUnit#PROP_NAME} updates
     * the name of the topcomponent
     */
    private class NameUpdater implements PropertyChangeListener {

        @Override
        public void propertyChange(PropertyChangeEvent pce) {
            if (pce.getPropertyName().equals(CropProductionUnit.PROP_NAME)) {
                updateName();
            }
        }
    }
}
