/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.lang.reflect.InvocationTargetException;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.util.swing.FormRow;
import org.openide.explorer.propertysheet.PropertyPanel;
import org.openide.nodes.Node;
import org.openide.nodes.PropertySupport;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;

/**
 * Overview panel for {@link CropProductionUnit} 's
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 * @author Wytse Visser
 * @author Merijn Zengers
 */
@NbBundle.Messages({
    "CropProductionUnitDataPanel color label text=Color:"})
public class CropProductionUnitDataPanel extends CropProductionUnitDetailsPanel {
    
    private PropertyPanel colorPicker;
    private final CropProductionUnit cropProductionUnit;
    Node.Property colorProp;
    
    public CropProductionUnitDataPanel(CropProductionUnit cropProductionUnit) {
        super(cropProductionUnit);
        this.cropProductionUnit = cropProductionUnit;
        initComponents();
    }
    
    private void initComponents() {
        cropProductionUnit.addPropertyChangeListener(CropProductionUnit.PROP_COLOR, new ColorChangeListener());
        colorPicker = createPropertyPanel();
        add(new FormRow(false, Bundle.CropProductionUnitDataPanel_color_label_text(), Bundle.CropProductionUnitDataPanel_color_label_text(), colorPicker));
    }

    /**
     * Create the property panel for color selection
     *
     * @return
     */
    private PropertyPanel createPropertyPanel() {
        try {
            colorProp = new PropertySupport.Reflection(cropProductionUnit, Color.class, CropProductionUnit.PROP_COLOR);
            return new PropertyPanel(colorProp);
        } catch (NoSuchMethodException ex) {
            Exceptions.printStackTrace(ex);
        }
        return null;
    }

    /**
     * Get the selected color for the {@link CropProductionUnit}
     *
     * @return the selected {@link Color} or null if no Color is set
     */
    public Color getSelectedCropProductionUnitColor() {
        Object selectedColor = colorProp.getPropertyEditor().getValue();
        if (selectedColor instanceof Color) {
            return (Color) selectedColor;
        }
        return null;
    }

    /**
     * Set the color for the {@link CropProductionUnit}
     *
     * @param color The color to set
     */
    private void setSelectedCropProductionUnitColor(Color color) {
        colorProp.getPropertyEditor().setValue(color);
        colorPicker.repaint();
    }

    /**
     * Listener to changes in the color of the {@link CropProductionUnit}
     */
    private class ColorChangeListener implements PropertyChangeListener {
        
        @Override
        public void propertyChange(PropertyChangeEvent pce) {
            if (pce.getPropertyName().equals(CropProductionUnit.PROP_COLOR)) {
                setSelectedCropProductionUnitColor((Color) pce.getNewValue());
            }
        }
    }
}
