/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.util.ArrayList;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.productionunit.wizard.NewCropProductionUnitAction;
import org.netbeans.api.project.Project;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.datatransfer.PasteType;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@NbBundle.Messages({"CropProductionUnit_root_node_display_name=Production units"})
public class CropProductionUnitRootNode extends FilterNode {

    private static final String ICON = "nl/cloudfarming/client/productionunit/folder_green16.png";
    private Project project;

    public CropProductionUnitRootNode(Node original, Project project) {
        super(original, new FilterNode.Children(original), project.getLookup());
        this.project = project;
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(ICON);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public String getDisplayName() {
        return Bundle.CropProductionUnit_root_node_display_name();
    }

    @Override
    public Action[] getActions(boolean context) {
        List<Action> actions = new ArrayList<>();

        actions.add(new NewCropProductionUnitAction(project));

        return actions.toArray(new Action[actions.size()]);
    }

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null; //dropping other nodes on this node is not supported
    }
}
