/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.farm.FarmProject;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@NodeFactory.Registration(projectType = FarmProject.PROJECT_TYPE)
public class CropProductionUnitRootNodeFactory implements NodeFactory {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.farm.productionunit");

    @Override
    public NodeList<?> createNodes(Project project) {
        List<Node> nodes = new ArrayList<>();

        nodes.add(new CropProductionUnitRootNode(getProductionUnitDirectoryNodeDelegate(project), project));

        return NodeFactorySupport.fixedNodeList(nodes.toArray(new Node[nodes.size()]));
    }

    private Node getProductionUnitDirectoryNodeDelegate(Project project) {
        FileObject productionUnitDir = project.getProjectDirectory().getFileObject(CropProductionUnitManagerImpl.CROP_PRODUCTION_UNIT_DIR);
        if (productionUnitDir == null) {
            try {
                productionUnitDir = project.getProjectDirectory().createFolder(CropProductionUnitManagerImpl.CROP_PRODUCTION_UNIT_DIR);
            } catch (IOException ex) {
                LOGGER.log(Level.WARNING, "Could not get production unit directory {0}", new Object[]{ex.getMessage()});
                return new AbstractNode(Children.LEAF);
            }
        }
        DataFolder productionUnitDataFolder = DataFolder.findFolder(productionUnitDir);
        return productionUnitDataFolder.getNodeDelegate();
    }
}
