/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.event.ActionEvent;
import java.util.ArrayList;
import java.util.List;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.farm.model.CropProductionUnitManager;
import org.openide.awt.ActionID;
import org.openide.awt.ActionRegistration;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Remove action for one or more {@link CropField}
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@ActionID(category = "Cropfield", id = "nl.cloudfarming.client.productionunit.RemoveCropfieldAction")
@ActionRegistration(displayName = "Remove cropfield")
@NbBundle.Messages({"RemoveCropfieldAction_action_name=Remove cropfield"})
public class RemoveCropFieldAction extends AbstractAction {

    private List<CropField> cropFields;

    public RemoveCropFieldAction(List<Node> selectedNodes) {
        super(Bundle.RemoveCropfieldAction_action_name());
        cropFields = new ArrayList<>();
        for (Node node : selectedNodes) {
            if (node.getLookup().lookup(CropField.class) != null) {
                cropFields.add(node.getLookup().lookup(CropField.class));
            }
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        CropProductionUnitManager manager = Lookup.getDefault().lookup(CropProductionUnitManager.class);
        for (CropField cropField : cropFields) {
            CropProductionUnit cropProductionUnit = manager.find(cropField.getParentURI());
            if (cropProductionUnit != null) {
                cropProductionUnit.removeCropField(cropField);
            }
        }
    }
}
