/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit.wizard;

import java.util.HashSet;
import java.util.Set;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.productionunit.CropProductionUnitDetailsController;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.HelpCtx;

/**
 * Controller for the {@link CropProductionUnitInputPanelVisual}
 *
 * @author Merijn Zengers
 */
public class CropProductionUnitInputPanel extends CropProductionUnitDetailsController implements WizardDescriptor.ValidatingPanel<WizardDescriptor> {

    private final Set<ChangeListener> listeners = new HashSet<>(1);
    private CropProductionUnit cropProductionUnit;

    public CropProductionUnitInputPanel(CropProductionUnit cropProductionUnit) {
        super(new CropProductionUnitInputPanelVisual(cropProductionUnit));
        this.cropProductionUnit = cropProductionUnit;

    }

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        return super.getComponent();
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx("help.key.here");
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(CropProductionUnitWizardAction.CPU, cropProductionUnit);
    }

    @Override
    public void validate() throws WizardValidationException {
        if (!super.isPanelValid()) {
            super.validatePanel();
            //Put in empty message whe only want to stop advancing to the next panel 
            throw new WizardValidationException(getComponent(), "", "");
        }

    }
}
