/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit.wizard;

import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

@NbBundle.Messages({
    "CropProductionUnitSummaryPanel_title=New production unit summary",
    "CropProductionUnitSummaryPanel_step_name=Input summary"
})
public class CropProductionUnitSummaryPanel implements WizardDescriptor.Panel<WizardDescriptor> {

    private ASBodyPanel component;
    private CropProductionUnitSummaryPanelVisual visualComponent;
    private static final String ICON = "nl/cloudfarming/client/productionunit/green32.png";

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        if (component == null) {
            visualComponent = new CropProductionUnitSummaryPanelVisual();
            component = new ASBodyPanel(visualComponent);
            component.setTitle(Bundle.CropProductionUnitSummaryPanel_title());
            component.setIcon(ImageUtilities.loadImageIcon(ICON, false));
            component.setName(Bundle.CropProductionUnitSummaryPanel_step_name());
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        return HelpCtx.DEFAULT_HELP;
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        if (wiz != null) {
            CropProductionUnit cpu = (CropProductionUnit) wiz.getProperty(CropProductionUnitWizardAction.CPU);
            visualComponent.setProductionUnitName(cpu.getName());
            visualComponent.setProductionUnitDescription(cpu.getDescription() != null ? cpu.getDescription() : "");
            visualComponent.setProductionUnitStartDate(cpu.getStartDate());
            visualComponent.setProductionUnitEndDate(cpu.getEndDate());
            visualComponent.setProductionUnitCrop(cpu.getCrop());
            visualComponent.setProductionUnitClassification(cpu.getClassification());
            visualComponent.setProductionUnitVariety(cpu.getVariety());
        }
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
    }
}
