/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.productionunit.wizard;

import java.text.DateFormat;
import java.util.Date;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.Variety;
import org.openide.util.NbBundle;

@NbBundle.Messages({
    "CropProductionUnitSummaryPanelVisual summary label text=Please review the data you entered before pressing finish.",
    "CropProductionUnitSummaryPanelVisual production unit name label text=Production unit name:",
    "CropProductionUnitSummaryPanelVisual production unit description label text=Production unit description:",
    "CropProductionUnitSummaryPanelVisual production unit start date label text=Start date:",
    "CropProductionUnitSummaryPanelVisual production unit end date label text=End date:",
    "CropProductionUnitSummaryPanelVisual production unit crop label text=Crop:",
    "CropProductionUnitSummaryPanelVisual production unit classification label text=Classification:",
    "CropProductionUnitSummaryPanelVisual production unit variety label text=Variety:"})
public final class CropProductionUnitSummaryPanelVisual extends JPanel {

    private JLabel summaryLabel;
    private JLabel productionUnitNameLabel;
    private JLabel productionUnitNameValueLabel;
    private JLabel productionUnitDescriptionLabel;
    private JLabel productionUnitDescriptionValueLabel;
    private JLabel productionUnitStartDateLabel;
    private JLabel productionUnitStartDateValueLabel;
    private JLabel productionUnitEndDateLabel;
    private JLabel productionUnitEndDateValueLabel;
    private JLabel productionUnitCropDefinitionLabel;
    private JLabel productionUnitCropDefinitionValueLabel;
    private JLabel productionUnitClassificationLabel;
    private JLabel productionUnitClassificationValueLabel;
    private JLabel productionUnitVarietyLabel;
    private JLabel productionUnitVarietyValueLabel;
    private DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MEDIUM);

    /**
     * Creates new form CropProductionUnitSummaryPanel
     */
    public CropProductionUnitSummaryPanelVisual() {
        init();
    }

    @Override
    public String getName() {
        return "Step #2";
    }
    
    private void init() {
        setLayout(new MigLayout("wrap 2"));
        productionUnitNameValueLabel = new JLabel();
        productionUnitDescriptionValueLabel = new JLabel();
        productionUnitStartDateValueLabel = new JLabel();
        productionUnitEndDateValueLabel = new JLabel();
        productionUnitCropDefinitionValueLabel = new JLabel();
        productionUnitClassificationValueLabel = new JLabel();
        productionUnitVarietyValueLabel = new JLabel();

        summaryLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_summary_label_text());
        productionUnitNameLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_name_label_text());
        productionUnitDescriptionLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_description_label_text());
        productionUnitStartDateLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_start_date_label_text());
        productionUnitEndDateLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_end_date_label_text());
        productionUnitCropDefinitionLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_crop_label_text());
        productionUnitClassificationLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_classification_label_text());
        productionUnitVarietyLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_variety_label_text());

        add(summaryLabel, "span 2");

        add(productionUnitNameLabel, "gaptop 40px");
        add(productionUnitNameValueLabel);

        add(productionUnitDescriptionLabel);
        add(productionUnitDescriptionValueLabel);

        add(productionUnitStartDateLabel);
        add(productionUnitStartDateValueLabel);

        add(productionUnitEndDateLabel);
        add(productionUnitEndDateValueLabel);

        add(productionUnitCropDefinitionLabel);
        add(productionUnitCropDefinitionValueLabel);

        add(productionUnitVarietyLabel);
        add(productionUnitVarietyValueLabel);

        add(productionUnitClassificationLabel);
        add(productionUnitClassificationValueLabel);
    }

    public void setProductionUnitName(String name) {
        productionUnitNameValueLabel.setText(name);
    }

    public void setProductionUnitDescription(String description) {
        productionUnitDescriptionValueLabel.setText(description);
    }

    public void setProductionUnitStartDate(Date startDate) {
        productionUnitStartDateValueLabel.setText(startDate != null ? dateFormat.format(startDate) : "");
    }

    public void setProductionUnitEndDate(Date endDate) {
        productionUnitEndDateValueLabel.setText(endDate != null ? dateFormat.format(endDate) : "");
    }

    public void setProductionUnitCrop(Crop crop) {
        productionUnitCropDefinitionValueLabel.setText(crop != null ? crop.getName() : "");
    }

    public void setProductionUnitClassification(Classification classification) {
        productionUnitClassificationValueLabel.setText(classification != null ? classification.getName() : "");
    }

    public void setProductionUnitVariety(Variety variety) {
        productionUnitVarietyValueLabel.setText(variety != null ? variety.getName() : "");
    }
}
